@@ -330,11 +330,11 @@ read_mlx18_res <- function(path, x, ...) {
   # Path should not have duplicated structure of subdirectory, but if not present,
   # it should be added.
   if(exists("subfolder", x) & !(grepl(x[["subfolder"]], dirname(path), fixed=TRUE))) {
-    path <- file.path(dirname(path), x[["subfolder"]], "/")
+    path <- file.path(dirname(path), x[["subfolder"]], fsep="/")
+  } else {
+    path <- dirname(path)
   }
 
-  path <- dirname(path)
-
   res_file <- file.path(path, x$file)
 
   file_path <- if (!file.exists(res_file)) {
@@ -456,24 +456,30 @@ read_mlx18_pred <- function(path, x, ...) {
 #' @return data.table object
 #' @importFrom utils read.table
 #' @import data.table
-
 read_mlx_par_est <- function(path, x, ...) {
   sep <- ifelse(exists("sep", x), x$sep, ";")
-  xx <- setDT(read.table(path, sep = sep, header = TRUE))
-  if ("names" %in% names(x)) {
-    # This handles the case where the
-    nam <- x[["names"]]
-    do_more <- FALSE
-    if (length(nam) > ncol(xx)) {
-      nam <- nam[seq(1, ncol(xx))]
-    }
-    setnames(xx, seq_along(nam), nam)
-    if (do_more) {
-      nam <- x[["names"]]
-      nam <- nam[-seq(1, ncol(xx))]
-      xx <- xx[, (nam) := NA]
-    }
+  xx <- as.data.frame(read.table(path, sep = sep, header = TRUE))
+  val <- names(xx)[1]
+  names <- vapply(names(xx), function(v) {
+    if (val == v) return("PARAM")
+    if (grepl("^par", v, ignore.case=TRUE)) return("VALUE")
+    if (grepl("(^value|^val)", v, ignore.case=TRUE)) return("VALUE")
+    if (grepl("^r[.]?s[.]?e[.]?", v, ignore.case=TRUE)) return("RSE")
+    if (grepl("^s[.]?e[.]?", v, ignore.case=TRUE)) return("SE")
+    if (grepl("^pval", v, ignore.case=TRUE)) return("PVALUE")
+    v
+  }, character(1), USE.NAMES=TRUE)
+  names(xx) <- names
+
+  vals <- intersect(c("PARAM", "VALUE", "SE", "RSE", "PVALUE"), names(xx))
+  ensure <- setdiff(c("PARAM", "VALUE"), vals)
+  if (length(ensure) > 0) {
+    stop("cannot determine the following column name types: '",
+         paste(ensure, collapse="', '"), "'",
+         call.=FALSE)
   }
+  xx <- xx[,vals]
+  xx <- setDT(xx)
   xx
 }
 
