@@ -1,5 +1,5 @@
 helper_skip <- function() {
   ret <- isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))
   #ret
-  FALSE
+  TRUE # don't skip for now
 }
