@@ -632,7 +632,7 @@ if (helper_skip()) {
   test_that("get_plot: params: ctr, nplot, which_pages  result: identical inherits", {
     ctr <- pmxClassHelpers$ctr
     get_p <- get_plot(ctr, nplot = "individual", which_pages = 1)
-    expect_true(inherits(get_p, c("gg", "ggplot")))
+    expect_true(is_ggplot(get_p))
   })
 
   test_that("get_plot: params: ctr, nplot, which_pages  result: error ctr is not a pmxClass", {
@@ -665,11 +665,7 @@ if (helper_skip()) {
   test_that("get_plot: params: ctr, nplot, which_pages  result: identical names", {
     ctr <- pmxClassHelpers$ctr
     get_p <- get_plot(ctr, nplot = "individual", which_pages = 1L)
-    gplNames <- c(
-      "data", "layers", "scales", "mapping", "theme", "coordinates",
-      "facet", "plot_env", "labels"
-    )
-    expect_identical(gplNames, names(get_p))
+    expect_true(is_ggplot(get_p))
   })
 
   #------------------- get_plot - end --------------------------------------------
@@ -917,7 +913,11 @@ if (helper_skip()) {
   )
 
   test_that("pmx_print: params NULL result: error missing arguments", {
-    expect_error(pmx_print())
+    expect_error(
+      ignore <- capture.output({
+        pmx_print()
+      })
+    )
   })
 
   test_that("pmx_print can print pmx class", {
@@ -925,7 +925,11 @@ if (helper_skip()) {
   })
 
   test_that("pmx_print  params: self, private; result: identical inherits", {
-    expect_true(inherits(pmx_print(self, private), "pmxConfig"))
+    # assign without printing
+    capture.output({
+      pmx_pr <- pmx_print(self, private)
+    })
+    expect_true(inherits(pmx_pr, "pmxConfig"))
   })
 
 
@@ -971,7 +975,10 @@ if (helper_skip()) {
   })
 
   test_that("pmx_print params: self, private; result: identical structure", {
-    pmx_pr <- pmx_print(self, private)
+    # assign quietly
+    capture.output({
+      pmx_pr <- pmx_print(self, private)
+    })
     expect_identical(pmx_pr$sys, "mlx")
     expect_identical(pmx_pr$plots$ABS_IWRES_IPRED$ptype, "SCATTER")
   })
@@ -1031,7 +1038,8 @@ if (helper_skip()) {
 
   test_that("print.pmxClass: params ctr is a pmxClass obj; result: identical inherits", {
     ctr <- theophylline()
-    expect_true(inherits(print.pmxClass(ctr), "pmxConfig"))
+    tmp <- capture.output(ctr_print <- print.pmxClass(ctr)) # assign quietly
+    expect_true(inherits(ctr_print, "pmxConfig"))
   })
   #------------------- print.pmxClass - end --------------------------------------
 
